#!/usr/bin/env bash

action() {

    # law + luigi env variables
    local base="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
    export LAW_HOME="$base/.law"
    export LAW_CONFIG_FILE="$base/law.cfg"
    export LUIGI_CONFIG_PATH="$base/luigi.cfg"
    export ANALYSIS_PATH="$base"
    export ANALYSIS_DATA_PATH="$ANALYSIS_PATH/data"

    # luigi + law
    export PATH="$base/law/bin:$base/luigi/bin:$PATH"
    export PYTHONPATH="$base/law:$base/luigi:$base/six:$base/enum34-1.1.10:$base/python-dateutil-2.8.2:$base:$PYTHONPATH"

    # fastNLO tools (mostly perl scripts)
    # Required to merge fastwarm results for example
    # Add local user path of git checkout, e.g.
    export PATH="$HOME/git/fastNLO/tools:$PATH"

    # fastNLO plotting (needs python3, matplotlib3, numpy, scipy)
    # Required to produce any plots
    # --> Does not work on ETP portals with Centos7 like bms1,3!
    # --> Use your more modern Desktop PC e.g. with Ubuntu and properly set PATH and PYTHONPATH
    # Rivet only works with python2
    # Add local user paths for fastNLO plottings with python3 usage, e.g.
    #    export PATH="$HOME/git/fastNLO/tools/plotting:$HOME/local/bin:$PATH"
    export PATH="$HOME/git/fastNLO/tools/plotting:$HOME/local.lx25-python2/bin:$PATH"
    #    export PYTHONPATH="$HOME/local/lib/python3.8/site-packages:$PYTHONPATH"
    export PYTHONPATH="$HOME/local.lx25-python2/lib/python2.7/site-packages:$PYTHONPATH"

    # gfal2, not required for plotting
    # SLC6
    # source /cvmfs/grid.cern.ch/emi3ui-latest/etc/profile.d/setup-ui-example.sh
    # C7
    #    source /cvmfs/grid.cern.ch/centos7-ui-v03/etc/profile.d/setup-c7-ui-example.sh

    # NNLOJET + APPLfast
    # Uses grid install; does not use fastNLO extension compiled with python2
    #    source /cvmfs/etp.kit.edu/fnlo/src/fnlosrc_source_NNLOJET-5419.sh
    #    source /cvmfs/etp.kit.edu/fastnnlo-bridge-0.0.46/src/fnlosrc_source_NNLOJET_rev5918.sh
    # If fastNLO version of grid install in /cvmfs/etp.kit.edu not new enough for evaluation,
    # then use local install on bms1/3:
    #    export PATH="$HOME/local.s9/bin:$PATH"
    #    export LD_LIBRARY_PATH="$HOME/local.s9/lib:$LD_LIBRARY_PATH"
    # For plotting must use local install e.g. on lx25 with fastNLO extension compiled with python3
    #    source $HOME/local/src/fnlosrc_source.sh
    # Rivet only works with python2
    source $HOME/local.lx25-python2/src/fnlosrc_source.sh

    source "$( law completion )"
}
action
